summaryrefslogtreecommitdiffstats
path: root/tdecore/tdeconfigbackend.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/tdeconfigbackend.h')
-rw-r--r--tdecore/tdeconfigbackend.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdecore/tdeconfigbackend.h b/tdecore/tdeconfigbackend.h
index 916479643..05884cb7f 100644
--- a/tdecore/tdeconfigbackend.h
+++ b/tdecore/tdeconfigbackend.h
@@ -128,7 +128,7 @@ public:
/**
* Set the locale string that defines the current language.
* @param _localeString the identifier of the language
- * @see KLocale
+ * @see TDELocale
*/
void setLocaleString(const TQCString &_localeString) { localeString = _localeString; }
@@ -252,9 +252,9 @@ protected:
bool bGlobal = false, bool bDefault = false);
// Kubuntu patch, 2006-08-03
// looks up a key in with KLocale
// see https://launchpad.net/distros/ubuntu/+spec/langpacks-desktopfiles-kde
- void translateKey(KLocale& locale, TQCString currentGroup, TQCString key);
+ void translateKey(TDELocale& locale, TQCString currentGroup, TQCString key);
/**
* Writes configuration file back.
@@ -252,9 +252,9 @@ protected:
bool bGlobal = false, bool bDefault = false);
// Kubuntu patch, 2006-08-03
- // looks up a key in with KLocale
+ // looks up a key in with TDELocale
// see https://launchpad.net/distros/ubuntu/+spec/langpacks-desktopfiles-kde